<template>
  <div class="p-2">
    <transition :enter-active-class="proxy?.animate.searchAnimate.enter" :leave-active-class="proxy?.animate.searchAnimate.leave">
      <div v-show="showSearch" class="mb-[10px]">
        <el-card shadow="hover">
          <el-form ref="queryFormRef" :model="queryParams" :inline="true">
            <el-form-item label="批次号" prop="batchCode">
              <el-input v-model="queryParams.batchCode" placeholder="请输入批次号" clearable @keyup.enter="handleQuery" />
            </el-form-item>
            <el-form-item label="测试项目" prop="testItem">
              <el-select v-model="selectedTestItems" :multiple="true" placeholder="请选择测试项目" clearable @keyup.enter="handleQuery">
                <el-option v-for="item in testItemsOptions" :key="item.value" :label="item.label" :value="item.value" />
              </el-select>
            </el-form-item>
            <el-form-item label="创建时间" style="width: 308px">
              <el-date-picker
                v-model="dateRangeCreateTime"
                value-format="YYYY-MM-DD"
                type="daterange"
                range-separator="-"
                start-placeholder="开始日期"
                end-placeholder="结束日期"
                unlink-panels
                :default-time="[new Date(2000, 1, 1, 0, 0, 0), new Date(2000, 1, 1, 23, 59, 59)]"
              />
            </el-form-item>
            <el-form-item>
              <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
              <el-button icon="Refresh" @click="resetQuery">重置</el-button>
            </el-form-item>
          </el-form>
        </el-card>
      </div>
    </transition>

    <el-card shadow="never">
      <template #header>
        <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
            <el-button type="primary" plain icon="Plus" @click="handleAdd" v-hasPermi="['qms:testResult:add']">新增</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="success" plain icon="Edit" :disabled="single" @click="handleUpdate()" v-hasPermi="['qms:testResult:edit']">修改</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="danger" plain icon="Delete" :disabled="multiple" @click="handleDelete()" v-hasPermi="['qms:testResult:remove']">删除</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="warning" plain icon="Download" @click="handleExport" v-hasPermi="['qms:testResult:export']">导出</el-button>
          </el-col>
          <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>
        </el-row>
      </template>

      <el-table v-loading="loading" :data="testResultList" @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55" align="center" />
        <el-table-column label="" align="center" prop="id" v-if="false" />
        <el-table-column label="批次号" align="center" prop="batchCode" />
        <el-table-column label="测试序号" align="center" prop="testNum" />
        <el-table-column label="测试项目" align="center" prop="testItem" />
        <el-table-column label="实际电压" align="center" prop="voltage" />
        <el-table-column label="实际电流" align="center" prop="loadCurrent" />
        <el-table-column label="标准距离" align="center" prop="stdDistance" />
        <el-table-column label="感应物" align="center" prop="inductor" />
        <el-table-column label="输出引脚" align="center" prop="output" />
        <el-table-column label="测试数据" align="center" prop="testValue" />
        <el-table-column label="判断条件" align="center" prop="judgeDetail" />
        <el-table-column label="测试结果" align="center" prop="testResult" />
        <el-table-column label="备注" align="center" prop="remark" />
        <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
          <template #default="scope">
            <el-tooltip content="修改" placement="top">
              <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)" v-hasPermi="['qms:testResult:edit']"></el-button>
            </el-tooltip>
            <el-tooltip content="删除" placement="top">
              <el-button link type="primary" icon="Delete" @click="handleDelete(scope.row)" v-hasPermi="['qms:testResult:remove']"></el-button>
            </el-tooltip>
          </template>
        </el-table-column>
      </el-table>

<!--      <pagination v-show="total > 0" :total="total" v-model:page="queryParams.pageNum" v-model:limit="queryParams.pageSize" @pagination="getList" />-->
    </el-card>
    <!-- 添加或修改测试结果对话框 -->
    <el-dialog :title="dialog.title" v-model="dialog.visible" width="500px" append-to-body>
      <el-form ref="testResultFormRef" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="批次号" prop="batchCode">
          <el-input v-model="form.batchCode" placeholder="请输入批次号" />
        </el-form-item>
        <el-form-item label="测试序号" prop="testNum">
          <el-input v-model="form.testNum" placeholder="请输入测试序号" />
        </el-form-item>
        <el-form-item label="测试项目" prop="testItem">
          <el-select v-model="form.testItem" placeholder="请选择测试项目">
            <el-option v-for="item in testItemsOptions" :key="item.value" :label="item.label" :value="item.value" />
          </el-select>
        </el-form-item>
        <el-form-item label="实际电压" prop="voltage">
          <el-input v-model="form.voltage" placeholder="请输入实际电压" />
        </el-form-item>
        <el-form-item label="实际电流" prop="loadCurrent">
          <el-input v-model="form.loadCurrent" placeholder="请输入实际电流" />
        </el-form-item>
        <el-form-item label="标准距离" prop="stdDistance">
          <el-input v-model="form.stdDistance" placeholder="请输入标准距离" />
        </el-form-item>
        <el-form-item label="感应物" prop="inductor">
          <el-input v-model="form.inductor" placeholder="请输入感应物" />
        </el-form-item>
        <el-form-item label="输出引脚" prop="output">
          <el-input v-model="form.output" placeholder="请输入输出引脚" />
        </el-form-item>
        <el-form-item label="测试数据" prop="testValue">
          <el-input v-model="form.testValue" placeholder="请输入测试数据" />
        </el-form-item>
        <el-form-item label="判断条件" prop="judgeDetail">
          <el-input v-model="form.judgeDetail" placeholder="请输入判断条件" />
        </el-form-item>
        <el-form-item label="测试结果" prop="testResult">
          <el-input v-model="form.testResult" placeholder="请输入测试结果" />
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" placeholder="请输入备注" />
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button :loading="buttonLoading" type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="TestResult" lang="ts">
import { listTestResultAll, getTestResult, delTestResult, addTestResult, updateTestResult, listTestItem } from '@/api/qms/testResult';
import { TestResultVO, TestResultQuery, TestResultForm } from '@/api/qms/testResult/types';

const { proxy } = getCurrentInstance() as ComponentInternalInstance;

const testResultList = ref<TestResultVO[]>([]);
const buttonLoading = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref<Array<string | number>>([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const dateRangeCreateTime = ref<[DateModelType, DateModelType]>(['', '']);
const queryFormRef = ref<ElFormInstance>();
const testResultFormRef = ref<ElFormInstance>();

const testItemsOptions = ref<{ label: string, value: string }[]>([]); // 新增测试项目选项
const selectedTestItems = ref<string | string[]>([]); // 修改为兼容单选的类型

const dialog = reactive<DialogOption>({
  visible: false,
  title: ''
});

const initFormData: TestResultForm = {
  id: undefined,
  batchCode: undefined,
  testNum: undefined,
  testItem: undefined,
  voltage: undefined,
  loadCurrent: undefined,
  stdDistance: undefined,
  inductor: undefined,
  output: undefined,
  testValue: undefined,
  judgeDetail: undefined,
  testResult: undefined,
  remark: undefined
}
const data = reactive<PageData<TestResultForm, TestResultQuery>>({
  form: {...initFormData},
  queryParams: {
    batchCode: undefined,
    testNum: undefined,
    testItem: undefined,
    voltage: undefined,
    loadCurrent: undefined,
    stdDistance: undefined,
    inductor: undefined,
    output: undefined,
    testValue: undefined,
    judgeDetail: undefined,
    testResult: undefined,
    startTime: undefined, // 新增 startTime 字段
    endTime: undefined, // 新增 endTime 字段
    params: {
      createTime: undefined,
    }
  },
  rules: {
    id: [
      { required: true, message: "不能为空", trigger: "blur" }
    ],
    batchCode: [
      { required: true, message: "批次号不能为空", trigger: "blur" }
    ],
    testNum: [
      { required: true, message: "测试序号不能为空", trigger: "blur" }
    ],
    testItem: [
      { required: true, message: "测试项目不能为空", trigger: "blur" }
    ],
    voltage: [
      { required: true, message: "实际电压不能为空", trigger: "blur" }
    ],
    loadCurrent: [
      { required: true, message: "实际电流不能为空", trigger: "blur" }
    ],
    stdDistance: [
      { required: true, message: "标准距离不能为空", trigger: "blur" }
    ],
    inductor: [
      { required: true, message: "感应物不能为空", trigger: "blur" }
    ],
    output: [
      { required: true, message: "输出引脚不能为空", trigger: "blur" }
    ],
    testValue: [
      { required: true, message: "测试数据不能为空", trigger: "blur" }
    ],
    judgeDetail: [
      { required: true, message: "判断条件不能为空", trigger: "blur" }
    ],
    testResult: [
      { required: true, message: "测试结果不能为空", trigger: "blur" }
    ],
  }
});

const { queryParams, form, rules } = toRefs(data);

// 获取所有测试项目
const fetchTestItems = async () => {
  const res = await listTestItem();
  testItemsOptions.value = res.data.map(item => ({ label: item, value: item }));
}

/** 查询测试结果列表 */
const getList = async () => {
  loading.value = true;
  queryParams.value.params = {};
  // 处理 selectedTestItems 的值，兼容单选和多选
  if (Array.isArray(selectedTestItems.value)) {
    queryParams.value.testItem = selectedTestItems.value.join(','); // 多选模式
  } else {
    queryParams.value.testItem = selectedTestItems.value; // 单选模式
  }
  proxy?.addDateRange(queryParams.value, dateRangeCreateTime.value, 'CreateTime');
  const res = await listTestResultAll(queryParams.value);
  testResultList.value = res.data;
  loading.value = false;
}

/** 取消按钮 */
const cancel = () => {
  reset();
  dialog.visible = false;
}

/** 表单重置 */
const reset = () => {
  form.value = {...initFormData};

  testResultFormRef.value?.resetFields();
}

/** 搜索按钮操作 */
const handleQuery = () => {
  console.log("queryParams::",queryParams.value)
  getList();
}

/** 重置按钮操作 */
const resetQuery = () => {
  dateRangeCreateTime.value = ['', ''];
  queryFormRef.value?.resetFields();
  selectedTestItems.value = []; // 重置选中的测试项目
  reset(); // 调用重置方法以清空时间段字段
}

/** 多选框选中数据 */
const handleSelectionChange = (selection: TestResultVO[]) => {
  ids.value = selection.map(item => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
const handleAdd = () => {
  reset();
  dialog.visible = true;
  dialog.title = "添加测试结果";
}

/** 修改按钮操作 */
const handleUpdate = async (row?: TestResultVO) => {
  reset();
  const _id = row?.id || ids.value[0]
  const res = await getTestResult(_id);
  Object.assign(form.value, res.data);
  dialog.visible = true;
  dialog.title = "修改测试结果";
}

/** 提交按钮 */
const submitForm = () => {
  testResultFormRef.value?.validate(async (valid: boolean) => {
    if (valid) {
      buttonLoading.value = true;
      if (form.value.id) {
        await updateTestResult(form.value).finally(() =>  buttonLoading.value = false);
      } else {
        await addTestResult(form.value).finally(() =>  buttonLoading.value = false);
      }
      proxy?.$modal.msgSuccess("操作成功");
      dialog.visible = false;
      await getList();
    }
  });
}

/** 删除按钮操作 */
const handleDelete = async (row?: TestResultVO) => {
  const _ids = row?.id || ids.value;
  await proxy?.$modal.confirm('是否确认删除测试结果编号为"' + _ids + '"的数据项？').finally(() => loading.value = false);
  await delTestResult(_ids);
  proxy?.$modal.msgSuccess("删除成功");
  await getList();
}

/** 导出按钮操作 */
const handleExport = () => {
  proxy?.download('qms/testResult/export', {
    ...queryParams.value
  }, `testResult_${new Date().getTime()}.xlsx`)
}

onMounted(() => {
  getList();
  fetchTestItems(); // 调用获取测试项目接口
});
</script>
